﻿using Mediachase.Commerce.Orders;
using Mediachase.MetaDataPlus.Configurator;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;
using System.Text;

namespace EPiServer.Business.Commerce.Payment.DataCash.Orders
{
    /// <summary>
    /// Represents Payment class for DataCash.
    /// </summary>
    [Serializable]
    public class DataCashPayment : Mediachase.Commerce.Orders.Payment
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="PayPalPayment"/> class.
        /// </summary>
        public DataCashPayment()
            : base(DataCashPaymentMetaClass)
        {
            this.PaymentType = Mediachase.Commerce.Orders.PaymentType.Other;
            ImplementationClass = this.GetType().AssemblyQualifiedName; // need to have assembly name in order to retreive the correct type in ClassInfo
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PayPalPayment"/> class.
        /// </summary>
        /// <param name="info">The info.</param>
        /// <param name="context">The context.</param>
        protected DataCashPayment(SerializationInfo info, StreamingContext context)
            : base(info, context) 
        {
            this.PaymentType = Mediachase.Commerce.Orders.PaymentType.Other;
            ImplementationClass = this.GetType().AssemblyQualifiedName; // need to have assembly name in order to retreive the correct type in ClassInfo
        }

        private static MetaClass _MetaClass;
        /// <summary>
        /// Gets the credit card payment meta class.
        /// </summary>
        /// <value>The credit card payment meta class.</value>
        public static MetaClass DataCashPaymentMetaClass
        {
            get
            {
                if (_MetaClass == null)
                {
                    _MetaClass = MetaClass.Load(OrderContext.MetaDataContext, "DataCashPayment");
                }

                return _MetaClass;
            }
        }

        /// <summary>
        /// Represents the DataCash reference string
        /// </summary>
        public string DataCashReference
        {
            get { return GetString("DataCashReference"); }
            set { this["DataCashReference"] = value; }
        }

        /// <summary>
        /// Represents the DataCash authenticate code
        /// </summary>
        public string DataCashAuthenticateCode
        {
            get { return GetString("DataCashAuthenticateCode"); }
            set { this["DataCashAuthenticateCode"] = value; }
        }

        /// <summary>
        /// Represents the merchant reference, which is a unique reference number for each transaction (Min 6, max 30 alphanumeric character)
        /// </summary>
        public string DataCashMerchantReference
        {
            get { return GetString("DataCashMerchantReference"); }
            set { this["DataCashMerchantReference"] = value; }
        }

        
    }
}
