﻿using System;
using System.Collections.Generic;
using System.Text;
using Mediachase.MetaDataPlus.Configurator;
using Mediachase.MetaDataPlus;
using System.Runtime.Serialization;
using Mediachase.Commerce.Orders;

namespace EPiServer.Business.Commerce.Payment.Klarna.Orders
{
    /// <summary>
    /// Represents Payment class for Klarna.
    /// </summary>
    [Serializable]
    public class KlarnaPayment : Mediachase.Commerce.Orders.Payment
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="CreditCardPayment"/> class.
        /// </summary>
        public KlarnaPayment()
            : base(KlarnaPaymentMetaClass)
        {
            this.PaymentType = PaymentType.Other;
            ImplementationClass = this.GetType().AssemblyQualifiedName; // need to have assembly name in order to retreive the correct type in ClassInfo
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="KlarnaPayment"/> class.
        /// </summary>
        /// <param name="info">The info.</param>
        /// <param name="context">The context.</param>
        protected KlarnaPayment(SerializationInfo info, StreamingContext context)
            : base(info, context) 
        {
            this.PaymentType = PaymentType.Other;
            ImplementationClass = this.GetType().AssemblyQualifiedName; // need to have assembly name in order to retreive the correct type in ClassInfo
        }

        private static MetaClass _MetaClass;
        /// <summary>
        /// Gets the credit card payment meta class.
        /// </summary>
        /// <value>The credit card payment meta class.</value>
        public static MetaClass KlarnaPaymentMetaClass
        {
            get
            {
                if (_MetaClass == null)
                {
                    _MetaClass = MetaClass.Load(OrderContext.MetaDataContext, "KlarnaPayment");
                }

                return _MetaClass;
            }
        }

        /// <summary>
        /// Represents the Social security number
        /// </summary>
        public string SocialSecurityNo
        {
            get { return GetString("SocialSecurityNo"); }
            set { this["SocialSecurityNo"] = value; }
        }

        /// <summary>
        /// Represents the Germany house number
        /// </summary>
        public string GermanyHouseNumberText
        {
            get { return GetString("GermanyHouseNumberText"); }
            set { this["GermanyHouseNumberText"] = value; }
        }

        /// <summary>
        /// Represents the Netherlands house number
        /// </summary>
        public string NetherlandsHouseNumberText
        {
            get { return GetString("NetherlandsHouseNumberText"); }
            set { this["NetherlandsHouseNumberText"] = value; }
        }

        /// <summary>
        /// Represents the Netherlands house extension
        /// </summary>
        public string NetherlandsHouseExtensionText
        {
            get { return GetString("NetherlandsHouseExtensionText"); }
            set { this["NetherlandsHouseExtensionText"] = value; }
        }

        /// <summary>
        /// Represents the PclassId
        /// </summary>
        public string PclassId
        {
            get { return GetString("PclassId"); }
            set { this["PclassId"] = value; }
        }
    }
}
