﻿using System;
using Mediachase.Web.Console.Interfaces;
using Mediachase.Commerce.Orders.Dto;
using System.Data;

namespace EPiServer.Business.Commerce.Payment.PayPal
{
    public partial class ConfigurePayment : System.Web.UI.UserControl, IGatewayControl
    {
        // Fields
        private PaymentMethodDto _paymentMethodDto;
        private string _validationGroup;

        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurePayment"/> class.
        /// </summary>
        public ConfigurePayment()
        {
            this._validationGroup = string.Empty;
            this._paymentMethodDto = null;
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            this.BindData();
        }

        /// <summary>
        /// Binds the data.
        /// </summary>
        public void BindData()
        {
            if ((this._paymentMethodDto != null) && (this._paymentMethodDto.PaymentMethodParameter != null))
            {
                PaymentMethodDto.PaymentMethodParameterRow parameterByName = null;
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.UserParameter);
                if (parameterByName != null)
                {
                    this.APIUser.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.PALParameter);
                if (parameterByName != null)
                {
                    this.PAL.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.PasswordParameter);
                if (parameterByName != null)
                {
                    this.Password.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.APISisnatureParameter);
                if (parameterByName != null)
                {
                    this.Signature.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.SandBoxParameter);
                if (parameterByName != null)
                {
                    this.CheckBoxTest.Checked = parameterByName.Value == "1";
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.ExpChkoutURLParameter);
                if (parameterByName != null)
                {
                    this.ExpChkoutURL.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.BusinessEmailParameter);
                if (parameterByName != null)
                {
                    this.BusinessEmail.Text = parameterByName.Value;
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.AllowChangeAddressParameter);
                if (parameterByName != null)
                {
                    this.CheckBoxAllowChangeAddress.Checked = parameterByName.Value == "1";
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.SkipConfirmPageParameter);
                if (parameterByName != null)
                {
                    this.CheckBoxSkipConfirmPage.Checked = parameterByName.Value == "1";
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.AllowGuestParameter);
                if (parameterByName != null)
                {
                    this.CheckBoxGuestCheckout.Checked = parameterByName.Value == "1";
                }
                parameterByName = this.GetParameterByName(PayPalPaymentGateway.PaymentActionParameter);
                if (parameterByName != null)
                {
                    this.DropDownListPaymentAction.SelectedValue = parameterByName.Value;
                }
            }
            else
            {
                this.Visible = false;
            }
        }

        private PaymentMethodDto.PaymentMethodParameterRow GetParameterByName(string name)
        {
            return this._paymentMethodDto.GetParameterByName(name);
        }

        /// <summary>
        /// Create parameters (settings) for paymentMethodDto (which is PayPal).
        /// <example>APIUsername, APIPassword, PayPalCheckoutUrl, ...</example>
        /// </summary>
        /// <param name="dto">the PayPal payment method</param>
        /// <param name="name">param's name</param>
        /// <param name="value">param's value</param>
        /// <param name="paymentMethodId">id of PayPal payment method</param>
        private void CreateParameter(PaymentMethodDto dto, string name, string value, Guid paymentMethodId)
        {
            PaymentMethodDto.PaymentMethodParameterRow row = dto.PaymentMethodParameter.NewPaymentMethodParameterRow();
            row.PaymentMethodId = paymentMethodId;
            row.Parameter = name;
            row.Value = value;
            if (row.RowState == DataRowState.Detached)
            {
                dto.PaymentMethodParameter.Rows.Add(row);
            }
        }


        #region IGatewayControl Members

        /// <summary>
        /// Loads the PaymentMethodDto object
        /// </summary>
        /// <param name="dto">The PaymentMethodDto object</param>
        public void LoadObject(object dto)
        {
            this._paymentMethodDto = dto as PaymentMethodDto;
        }

        /// <summary>
        /// Saves the changes.
        /// </summary>
        /// <param name="dto">The dto.</param>
        public void SaveChanges(object dto)
        {
            if (this.Visible)
            {
                this._paymentMethodDto = dto as PaymentMethodDto;
                if ((this._paymentMethodDto != null) && (this._paymentMethodDto.PaymentMethodParameter != null))
                {
                    Guid paymentMethodId = Guid.Empty;
                    if (this._paymentMethodDto.PaymentMethod.Count > 0)
                    {
                        paymentMethodId = this._paymentMethodDto.PaymentMethod[0].PaymentMethodId;
                    }

                    PaymentMethodDto.PaymentMethodParameterRow parameterByName = null;
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.UserParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.APIUser.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.UserParameter, this.APIUser.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.BusinessEmailParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.BusinessEmail.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.BusinessEmailParameter, this.BusinessEmail.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.PALParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.PAL.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.PALParameter, this.PAL.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.PasswordParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.Password.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.PasswordParameter, this.Password.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.APISisnatureParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.Signature.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.APISisnatureParameter, this.Signature.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.ExpChkoutURLParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.ExpChkoutURL.Text;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.ExpChkoutURLParameter, this.ExpChkoutURL.Text, paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.SandBoxParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = (this.CheckBoxTest.Checked ? "1" : "0");
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.SandBoxParameter, (this.CheckBoxTest.Checked ? "1" : "0"), paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.AllowChangeAddressParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = (this.CheckBoxAllowChangeAddress.Checked ? "1" : "0");
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.AllowChangeAddressParameter, (this.CheckBoxAllowChangeAddress.Checked ? "1" : "0"), paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.SkipConfirmPageParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = (this.CheckBoxSkipConfirmPage.Checked ? "1" : "0");
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.SkipConfirmPageParameter, (this.CheckBoxSkipConfirmPage.Checked ? "1" : "0"), paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.AllowGuestParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = (this.CheckBoxGuestCheckout.Checked ? "1" : "0");
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.AllowGuestParameter, (this.CheckBoxGuestCheckout.Checked ? "1" : "0"), paymentMethodId);
                    }
                    parameterByName = this.GetParameterByName(PayPalPaymentGateway.PaymentActionParameter);
                    if (parameterByName != null)
                    {
                        parameterByName.Value = this.DropDownListPaymentAction.SelectedValue;
                    }
                    else
                    {
                        this.CreateParameter(this._paymentMethodDto, PayPalPaymentGateway.PaymentActionParameter, this.DropDownListPaymentAction.SelectedValue, paymentMethodId);
                    }
                }
            }

        }

        /// <summary>
        /// Gets or sets the validation group.
        /// </summary>
        /// <value>The validation group.</value>
        public string ValidationGroup
        {
            get
            {
                return _validationGroup;
            }
            set
            {
                _validationGroup = value;
            }
        }

        #endregion
    }
}